## 0.3.7 (2025-01-12)

### Fix

- dockerfile is required

## 0.3.6 (2025-01-12)

### Fix

- .docker needs to exist

## 0.3.5 (2025-01-12)

### Fix

- changelog

## 0.3.4 (2025-01-12)

### Fix

- changelog
- changelog

## 0.3.3 (2025-01-12)

### Fix

- changelog

## 0.3.2 (2025-01-12)

### Fix

- changelog

## 0.3.1 (2025-01-12)

### Fix

- changelog

## 0.3.0 (2025-01-12)

### Feat

- added functionality for dev containers

### Fix

- ensure that all packages are added to docker-compose
- package-d setup
- package tests should run when workspace dependencies change

### Refactor

- everything
- everything
- everything
- everything

## uvmono-0.3.8 (2025-01-12)
